@@ -1,40 +1,42 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.051/lib/Perl/Critic/Policy/BuiltinFunctions/ProhibitUniversalIsa.pm $
-#     $Date: 2007-04-12 01:26:09 -0700 (Thu, 12 Apr 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/BuiltinFunctions/ProhibitUniversalIsa.pm $
+#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
 #   $Author: thaljef $
-# $Revision: 1467 $
+# $Revision: 2721 $
 ##############################################################################
 
 package Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalIsa;
 
+use 5.006001;
 use strict;
 use warnings;
+use Readonly;
+
 use Perl::Critic::Utils qw{ :severities :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 1.051;
+our $VERSION = '1.092';
 
 #-----------------------------------------------------------------------------
 
-my $desc = q{UNIVERSAL::isa should not be used as a function};
-my $expl = q{Use eval{$obj->isa($pkg)} instead};  ##no critic 'RequireInterp';
+Readonly::Scalar my $DESC => q{UNIVERSAL::isa should not be used as a function};
+Readonly::Scalar my $EXPL => q{Use eval{$obj->isa($pkg)} instead};  ##no critic 'RequireInterp';
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return() }
-sub default_severity { return $SEVERITY_MEDIUM   }
-sub default_themes    { return qw( core maintenance )   }
-sub applies_to       { return 'PPI::Token::Word' }
+sub supported_parameters { return ()                     }
+sub default_severity     { return $SEVERITY_MEDIUM       }
+sub default_themes       { return qw( core maintenance ) }
+sub applies_to           { return 'PPI::Token::Word'     }
 
 #-----------------------------------------------------------------------------
 
 sub violates {
     my ( $self, $elem, undef ) = @_;
     return if !($elem eq 'isa' || $elem eq 'UNIVERSAL::isa');
-    return if ! is_function_call($elem);
-    return if $elem->parent()->isa('PPI::Statement::Include'); # allow 'use UNIVERSAL::isa;'
+    return if ! is_function_call($elem); # this also permits 'use UNIVERSAL::isa;'
 
-    return $self->violation( $desc, $expl, $elem );
+    return $self->violation( $DESC, $EXPL, $elem );
 }
 
 
@@ -48,12 +50,19 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalIsa
+Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalIsa - Write C<< eval { $foo->isa($pkg) } >> instead of C<UNIVERSAL::isa($foo, $pkg)>.
+
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
-  print UNIVERSAL::isa($obj, 'Foo::Bar') ? 'yes' : 'no';  #not ok
-  print eval { $obj->isa('Foo::Bar') } ? 'yes' : 'no';    #ok
+    print UNIVERSAL::isa($obj, 'Foo::Bar') ? 'yes' : 'no';  #not ok
+    print eval { $obj->isa('Foo::Bar') } ? 'yes' : 'no';    #ok
 
 As of Perl 5.9.3, the use of C<UNIVERSAL::isa> as a function has been
 deprecated and the method form is preferred instead.  Formerly, the
@@ -66,12 +75,18 @@ facades.
 Another alternative to UNIVERSAL::isa is the C<_INSTANCE> method of
 Param::Util, which is faster.
 
-See the CPAN module L<UNIVERSAL::isa> for an incendiary discussion of
-this topic.
+See the CPAN module L<UNIVERSAL::isa|UNIVERSAL::isa> for an incendiary
+discussion of this topic.
+
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
 
 =head1 SEE ALSO
 
-L<Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalCan>
+L<Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalCan|Perl::Critic::Policy::BuiltinFunctions::ProhibitUniversalCan>
 
 =head1 AUTHOR
 
@@ -79,7 +94,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006 Chris Dolan.  All rights reserved.
+Copyright (c) 2006-2008 Chris Dolan.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -94,4 +109,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
