@@ -1,33 +1,36 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.051/lib/Perl/Critic/Policy/InputOutput/RequireBracedFileHandleWithPrint.pm $
-#     $Date: 2007-04-12 01:26:09 -0700 (Thu, 12 Apr 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/InputOutput/RequireBracedFileHandleWithPrint.pm $
+#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
 #   $Author: thaljef $
-# $Revision: 1467 $
+# $Revision: 2721 $
 ##############################################################################
 
 package Perl::Critic::Policy::InputOutput::RequireBracedFileHandleWithPrint;
 
+use 5.006001;
 use strict;
 use warnings;
+use Readonly;
+
 use Perl::Critic::Utils qw{ :severities :classification :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 1.051;
+our $VERSION = '1.092';
 
 #-----------------------------------------------------------------------------
 
-my @postfix_words = qw( if unless for );
-my %postfix_words = hashify( @postfix_words );
+Readonly::Array my @POSTFIX_WORDS => qw( if unless for );
+Readonly::Hash my %POSTFIX_WORDS => hashify( @POSTFIX_WORDS );
 
-my $desc = q{File handle for "print" is not braced};
-my $expl = [ 217 ];
+Readonly::Scalar my $DESC => q{File handle for "print" is not braced};
+Readonly::Scalar my $EXPL => [ 217 ];
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return() }
-sub default_severity { return $SEVERITY_LOWEST   }
-sub default_themes    { return qw( core pbp cosmetic ) }
-sub applies_to       { return 'PPI::Token::Word' }
+sub supported_parameters { return ()                      }
+sub default_severity     { return $SEVERITY_LOWEST        }
+sub default_themes       { return qw( core pbp cosmetic ) }
+sub applies_to           { return 'PPI::Token::Word'      }
 
 #-----------------------------------------------------------------------------
 
@@ -42,7 +45,7 @@ sub violates {
     $sib[0] = $elem->snext_sibling();
     return if !$sib[0];
 
-    # Deal with situations where 'print' is called with parens
+    # Deal with situations where 'print' is called with parentheses
     if ( $sib[0]->isa('PPI::Structure::List') ) {
         my $expr = $sib[0]->schild(0);
         return if !$expr;
@@ -56,12 +59,12 @@ sub violates {
     return if !$sib[2];
 
     # First token must be a scalar symbol or bareword;
-    return if !( ($sib[0]->isa('PPI::Token::Symbol') && $sib[0] =~ m/\A \$/mx)
+    return if !( ($sib[0]->isa('PPI::Token::Symbol') && $sib[0] =~ m/\A \$/xms)
                  || $sib[0]->isa('PPI::Token::Word') );
 
     # First token must not be a builtin function or control
     return if is_perl_builtin($sib[0]);
-    return if exists $postfix_words{ $sib[0] };
+    return if exists $POSTFIX_WORDS{ $sib[0] };
 
     # Second token must be white space
     return if !$sib[1]->isa('PPI::Token::Whitespace');
@@ -70,11 +73,11 @@ sub violates {
     return if $sib[2]->isa('PPI::Token::Operator');
 
     # Special case for postfix controls
-    return if exists $postfix_words{ $sib[2] };
+    return if exists $POSTFIX_WORDS{ $sib[2] };
 
     return if $sib[0]->isa('PPI::Structure::Block');
 
-    return $self->violation( $desc, $expl, $elem );
+    return $self->violation( $DESC, $EXPL, $elem );
 }
 
 1;
@@ -87,7 +90,13 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::InputOutput::RequireBracedFileHandleWithPrint
+Perl::Critic::Policy::InputOutput::RequireBracedFileHandleWithPrint - Write C<print {$FH} $foo, $bar;> instead of C<print $FH $foo, $bar;>.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
@@ -105,13 +114,19 @@ else it won't compile under C<use strict 'subs'>.
   print  {STDERR}  $foo, $bar, $baz;  #won't compile under 'strict'
   print {*STDERR}  $foo, $bar, $baz;  #perfect!
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -126,4 +141,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
