@@ -1,30 +1,33 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.051/lib/Perl/Critic/Policy/Modules/ProhibitMultiplePackages.pm $
-#     $Date: 2007-04-12 01:26:09 -0700 (Thu, 12 Apr 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/Modules/ProhibitMultiplePackages.pm $
+#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
 #   $Author: thaljef $
-# $Revision: 1467 $
+# $Revision: 2721 $
 ##############################################################################
 
 package Perl::Critic::Policy::Modules::ProhibitMultiplePackages;
 
+use 5.006001;
 use strict;
 use warnings;
+use Readonly;
+
 use Perl::Critic::Utils qw{ :severities };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 1.051;
+our $VERSION = '1.092';
 
 #-----------------------------------------------------------------------------
 
-my $desc   = q{Multiple "package" declarations};
-my $expl   = q{Limit to one per file};
+Readonly::Scalar my $DESC   => q{Multiple "package" declarations};
+Readonly::Scalar my $EXPL   => q{Limit to one per file};
 
 #-----------------------------------------------------------------------------
 
 sub supported_parameters { return ()              }
-sub default_severity  { return $SEVERITY_HIGH  }
-sub default_themes    { return qw( core bugs ) }
-sub applies_to        { return 'PPI::Document' }
+sub default_severity     { return $SEVERITY_HIGH  }
+sub default_themes       { return qw( core bugs ) }
+sub applies_to           { return 'PPI::Document' }
 
 #-----------------------------------------------------------------------------
 
@@ -34,7 +37,7 @@ sub violates {
     return if !$nodes_ref;
     my @matches = @{$nodes_ref} > 1 ? @{$nodes_ref}[ 1 .. $#{$nodes_ref} ] :();
 
-    return map {$self->violation($desc, $expl, $_)} @matches;
+    return map {$self->violation($DESC, $EXPL, $_)} @matches;
 }
 
 1;
@@ -47,7 +50,14 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Modules::ProhibitMultiplePackages
+Perl::Critic::Policy::Modules::ProhibitMultiplePackages - Put packages (especially subclasses) in separate files.
+
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
@@ -57,13 +67,20 @@ methods or keywords in your editor, it makes it hard to find the right
 chunk of code, especially if each package is a subclass of the same
 base.
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
+
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -78,4 +95,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
