@@ -1,48 +1,49 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.051/lib/Perl/Critic/Policy/Subroutines/RequireFinalReturn.pm $
-#     $Date: 2007-04-12 01:26:09 -0700 (Thu, 12 Apr 2007) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-1.092/lib/Perl/Critic/Policy/Subroutines/RequireFinalReturn.pm $
+#     $Date: 2008-09-02 09:43:48 -0700 (Tue, 02 Sep 2008) $
 #   $Author: thaljef $
-# $Revision: 1467 $
+# $Revision: 2721 $
 ##############################################################################
 
 package Perl::Critic::Policy::Subroutines::RequireFinalReturn;
 
+use 5.006001;
 use strict;
 use warnings;
-use Carp qw(confess);
-use Perl::Critic::Utils qw{ :severities :data_conversion };
+use Readonly;
+
+use Perl::Critic::Exception::Fatal::Internal qw{ throw_internal };
+use Perl::Critic::Utils qw{ :characters :severities :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 1.051;
+our $VERSION = '1.092';
 
 #-----------------------------------------------------------------------------
 
-my $desc = q{Subroutine does not end with "return"};
-my $expl = [ 197 ];
+Readonly::Scalar my $DESC => q{Subroutine does not end with "return"};
+Readonly::Scalar my $EXPL => [ 197 ];
+
+Readonly::Hash my %CONDITIONALS => hashify( qw(if unless for foreach) );
 
 #-----------------------------------------------------------------------------
 
-sub supported_parameters { return qw(terminal_funcs)    }
-sub default_severity     { return $SEVERITY_HIGH        }
-sub default_themes       { return qw( core bugs pbp )   }
-sub applies_to           { return 'PPI::Statement::Sub' }
-
-#-----------------------------------------------------------------------------
-
-sub new {
-    my ( $class, %args ) = @_;
-    my $self = bless {}, $class;
-
-    my $user_terminals = $args{terminal_funcs} || q{};
-    my @user_terminals = words_from_string( $user_terminals );
-    my @default_terminals =
-        qw(exit die croak confess throw Carp::confess Carp::croak);
-
-    $self->{_terminals} = { hashify(@default_terminals, @user_terminals) };
-    $self->{_conditionals} = { hashify( qw(if unless for foreach) ) };
-    return $self;
+sub supported_parameters {
+    return (
+        {
+            name            => 'terminal_funcs',
+            description     => 'The additional subroutines to treat as terminal.',
+            default_string  => $EMPTY,
+            behavior        => 'string list',
+            list_always_present_values =>
+                [ qw< croak confess die exec exit throw Carp::confess Carp::croak > ],
+        },
+    );
 }
 
+sub default_severity { return $SEVERITY_HIGH        }
+sub default_themes   { return qw( core bugs pbp )   }
+sub applies_to       { return 'PPI::Statement::Sub' }
+
 #-----------------------------------------------------------------------------
 
 sub violates {
@@ -54,7 +55,7 @@ sub violates {
     my @blocks = grep {$_->isa('PPI::Structure::Block')} $elem->schildren();
     if (@blocks > 1) {
        # sanity check
-       confess 'Internal error: subroutine should have no more than one block';
+       throw_internal 'Subroutine should have no more than one block';
     }
     elsif (@blocks == 0) {
        #Technically, subroutines don't have to have a block at all. In
@@ -69,7 +70,7 @@ sub violates {
     }
 
     # Must be a violation
-    return $self->violation( $desc, $expl, $elem );
+    return $self->violation( $DESC, $EXPL, $elem );
 }
 
 #-----------------------------------------------------------------------------
@@ -97,7 +98,7 @@ sub _is_explicit_return {
 
     return if $self->_is_conditional_stmnt( $final );
     return $self->_is_return_or_goto_stmnt( $final )
-        || $self->_is_terminal_stmnt( $final, );
+        || $self->_is_terminal_stmnt( $final );
 }
 
 #-----------------------------------------------------------------------------
@@ -120,8 +121,8 @@ sub _is_compound_return {
                        !$_->isa('PPI::Token')} $final->schildren();
     # Sanity check:
     if (scalar grep {!$_->isa('PPI::Structure::Block')} @blocks) {
-        confess 'Internal error: expected only conditions, blocks and tokens in the if statement';
-        return; ## no critic (UnreachableCode)
+        throw_internal
+            'Expected only conditions, blocks and tokens in the if statement';
     }
 
     for my $block (@blocks) {
@@ -148,7 +149,7 @@ sub _is_terminal_stmnt {
     my ( $self, $stmnt ) = @_;
     return if not $stmnt->isa('PPI::Statement');
     my $first_token = $stmnt->schild(0) || return;
-    return exists $self->{_terminals}->{$first_token};
+    return exists $self->{_terminal_funcs}->{$first_token};
 }
 
 #-----------------------------------------------------------------------------
@@ -158,7 +159,7 @@ sub _is_conditional_stmnt {
     return if not $stmnt->isa('PPI::Statement');
     for my $elem ( $stmnt->schildren() ) {
         return 1 if $elem->isa('PPI::Token::Word')
-            && exists $self->{_conditionals}->{$elem};
+            && exists $CONDITIONALS{$elem};
     }
     return;
 }
@@ -173,52 +174,64 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Subroutines::RequireFinalReturn
+Perl::Critic::Policy::Subroutines::RequireFinalReturn - End every path through a subroutine with an explicit C<return> statement.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic|Perl::Critic>
+distribution.
+
 
 =head1 DESCRIPTION
 
-Require all subroutines to terminate explicitly with one of the following:
-C<return>, C<goto>, C<die>, C<exit>, C<throw>, C<carp> or C<croak>.
+Require all subroutines to terminate explicitly with one of the
+following: C<return>, C<carp>, C<croak>, C<die>, C<exec>, C<exit>,
+C<goto>, or C<throw>.
 
-Subroutines without explicit return statements at their ends can be confusing.
-It can be challenging to deduce what the return value will be.
+Subroutines without explicit return statements at their ends can be
+confusing.  It can be challenging to deduce what the return value will
+be.
 
-Furthermore, if the programmer did not mean for there to be a significant
-return value, and omits a return statement, some of the subroutine's inner
-data can leak to the outside.  Consider this case:
+Furthermore, if the programmer did not mean for there to be a
+significant return value, and omits a return statement, some of the
+subroutine's inner data can leak to the outside.  Consider this case:
 
-   package Password;
-   # every time the user guesses the password wrong, it's value
-   # is rotated by one character
-   my $password;
-   sub set_password {
-      $password = shift;
-   }
-   sub check_password {
-      my $guess = shift;
-      if ($guess eq $password) {
-         unlock_secrets();
-      } else {
-         $password = (substr $password, 1).(substr $password, 0, 1);
-      }
-   }
-   1;
+    package Password;
+    # every time the user guesses the password wrong, its value
+    # is rotated by one character
+    my $password;
+    sub set_password {
+        $password = shift;
+    }
+    sub check_password {
+        my $guess = shift;
+        if ($guess eq $password) {
+            unlock_secrets();
+        } else {
+            $password = (substr $password, 1).(substr $password, 0, 1);
+        }
+    }
+    1;
 
-In this case, the last statement in check_password() is the assignment.  The
-result of that assignment is the implicit return value, so a wrong guess
-returns the right password!  Adding a C<return;> at the end of that subroutine
-solves the problem.
+In this case, the last statement in check_password() is the
+assignment.  The result of that assignment is the implicit return
+value, so a wrong guess returns the right password!  Adding a
+C<return;> at the end of that subroutine solves the problem.
 
 The only exception allowed is an empty subroutine.
 
+Be careful when fixing problems identified by this Policy; don't
+blindly put a C<return;> statement at the end of every subroutine.
+
 =head1 CONFIGURATION
 
-If you've created your own terminal functions that behave like C<die> or
-C<exit>, then you can configure Perl::Critic to recognize those functions as
-well.  Just put something like this in your F<.perlcriticrc>:
+If you've created your own terminal functions that behave like C<die>
+or C<exit>, then you can configure Perl::Critic to recognize those
+functions as well.  Just put something like this in your
+F<.perlcriticrc>:
 
-  [Subroutines::RequireFinalReturns]
-  terminal_funcs = quit abort bailout
+    [Subroutines::RequireFinalReturns]
+    terminal_funcs = quit abort bailout
 
 =head1 LIMITATIONS
 
@@ -233,7 +246,7 @@ Chris Dolan <cdolan@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Chris Dolan.  All rights reserved.
+Copyright (c) 2005-2008 Chris Dolan.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -249,4 +262,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
